==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/Q2ExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { Q2ExpressionDescription } from "./Q2ExpressionDescription";
/**
 * @hidden
 */
var Q2ExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(Q2ExpressionDescriptionMetadata, _super);
    function Q2ExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Q2ExpressionDescriptionMetadata.b = function (a) {
        if (Q2ExpressionDescriptionMetadata.a == null) {
            Q2ExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            Q2ExpressionDescriptionMetadata.c(Q2ExpressionDescriptionMetadata.a);
        }
        if (a.j(Q2ExpressionDescriptionMetadata.a)) {
            return;
        }
        a.y(Q2ExpressionDescriptionMetadata.a);
    };
    Q2ExpressionDescriptionMetadata.c = function (a) {
        WrapperExpressionDescriptionMetadata.c(a);
    };
    Q2ExpressionDescriptionMetadata.d = function (a) {
        Q2ExpressionDescriptionMetadata.b(a);
        a.aa("Q2Expression", function () { return new Q2ExpressionDescription(); });
        a.z("Q2Expression", Q2ExpressionDescriptionMetadata.a);
    };
    Q2ExpressionDescriptionMetadata.$t = markType(Q2ExpressionDescriptionMetadata, 'Q2ExpressionDescriptionMetadata');
    Q2ExpressionDescriptionMetadata.a = null;
    return Q2ExpressionDescriptionMetadata;
}(Base));
export { Q2ExpressionDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/Q2ExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { Q2ExpressionDescription } from "./Q2ExpressionDescription";
/**
 * @hidden
 */
var Q2ExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(Q2ExpressionDescriptionMetadata, _super);
    function Q2ExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Q2ExpressionDescriptionMetadata.b = function (a) {
        if (Q2ExpressionDescriptionMetadata.a == null) {
            Q2ExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            Q2ExpressionDescriptionMetadata.c(Q2ExpressionDescriptionMetadata.a);
        }
        if (a.k(Q2ExpressionDescriptionMetadata.a)) {
            return;
        }
        a.aa(Q2ExpressionDescriptionMetadata.a);
    };
    Q2ExpressionDescriptionMetadata.c = function (a) {
        WrapperExpressionDescriptionMetadata.c(a);
    };
    Q2ExpressionDescriptionMetadata.d = function (a) {
        Q2ExpressionDescriptionMetadata.b(a);
        a.ac("Q2Expression", function () { return new Q2ExpressionDescription(); });
        a.ab("Q2Expression", Q2ExpressionDescriptionMetadata.a);
    };
    Q2ExpressionDescriptionMetadata.$t = markType(Q2ExpressionDescriptionMetadata, 'Q2ExpressionDescriptionMetadata');
    Q2ExpressionDescriptionMetadata.a = null;
    return Q2ExpressionDescriptionMetadata;
}(Base));
export { Q2ExpressionDescriptionMetadata };
